from src.mkslug import generate


class TestMakeSlug:
    def test_generate_regular_sentence(self):
        """
        Test generate function works successfully when a regular sentence provided.
        """

        slug = generate("Test slug value 1")

        assert slug == "The generated slug is:\ntest-slug-value-1"

    def test_generate_empty_sentence(self):
        """
        Test generate function works successfully when an empty sentence provided.
        """

        slug = generate("")

        assert slug == "The sentence must be populated. Please try again."

    def test_generate_special_characters_in_sentence(self):
        """
        Test generate function works successfully when a sentence provided has some special characters.
        """

        slug = generate("%Test slug ^*value$ 3.£$/")

        assert slug == "The generated slug is:\ntest-slug-value-3"

    def test_generate_multiple_spaces_in_sentence(self):
        """
        Test generate function works successfully when a sentence provided has multiple spaces.
        """

        slug = generate("    test    slug  value    4   ")

        assert slug == "The generated slug is:\ntest-slug-value-4"



import re


def generate(sentence: str) -> str:
    """
    Generate a slug from a sentence.

    Args:
        sentence: The sentence to check.

    Returns:
        generated slug value.
    """

    if not sentence:
        return "The sentence must be populated. Please try again."

    # Weed out unsavoury characters in the sentence
    sentence = re.sub("[^a-zA-Z0-9\s-]", "", sentence)

    # Change from one or more spaces to one hyphen
    slug = "-".join(sentence.split())

    slug = slug.lower()

    return f"The generated slug is:\n{slug}"



import sys
import mkslug


def main() -> None:

    try:
        sentence = sys.argv[1]
    except IndexError:
        raise SystemExit(
            "The sentence must be populated. For example: python -m 'How do you fix a car' in the terminal. Please try again."
        )

    slug = mkslug.generate(sentence)
    print(f"{slug}")


if __name__ == "__main__":
    main()
